@@ -136,16 +136,16 @@ class Hardware(IntEnum):
     Reserved_65535 = 65535
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Hardware':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Hardware(key)
         if key not in Hardware._member_map_:  # pylint: disable=no-member
             extend_enum(Hardware, key, default)
-        return Hardware[key]
+        return Hardware[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Hardware':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 65535):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
