@@ -11,7 +11,7 @@ class Certificate(IntEnum):
     """[Certificate] HIP Certificate Types"""
 
     #: Reserved [:rfc:`8002`]
-    Reserved = 0
+    Reserved_0 = 0
 
     #: X.509 v3 [:rfc:`8002`]
     X_509_v3 = 1
@@ -38,16 +38,16 @@ class Certificate(IntEnum):
     Obsoleted_8 = 8
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Certificate':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Certificate(key)
         if key not in Certificate._member_map_:  # pylint: disable=no-member
             extend_enum(Certificate, key, default)
-        return Certificate[key]
+        return Certificate[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Certificate':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 255):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
