@@ -26,16 +26,16 @@ class Cipher(IntEnum):
     AES_256_CBC = 4
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Cipher':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Cipher(key)
         if key not in Cipher._member_map_:  # pylint: disable=no-member
             extend_enum(Cipher, key, default)
-        return Cipher[key]
+        return Cipher[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Cipher':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 65535):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
