@@ -11,7 +11,7 @@ class ESPTransformSuite(IntEnum):
     """[ESPTransformSuite] ESP Transform Suite IDs"""
 
     #: RESERVED [:rfc:`7402`]
-    RESERVED = 0
+    RESERVED_0 = 0
 
     #: AES-128-CBC with HMAC-SHA1 [:rfc:`3602`][:rfc:`2404`]
     AES_128_CBC_with_HMAC_SHA1 = 1
@@ -59,16 +59,16 @@ class ESPTransformSuite(IntEnum):
     AES_GMAC = 15
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'ESPTransformSuite':
         """Backport support for original codes."""
         if isinstance(key, int):
             return ESPTransformSuite(key)
         if key not in ESPTransformSuite._member_map_:  # pylint: disable=no-member
             extend_enum(ESPTransformSuite, key, default)
-        return ESPTransformSuite[key]
+        return ESPTransformSuite[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'ESPTransformSuite':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 65535):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
