@@ -11,7 +11,7 @@ class HIAlgorithm(IntEnum):
     """[HIAlgorithm] HI Algorithm"""
 
     #: RESERVED [:rfc:`7401`]
-    RESERVED = 0
+    RESERVED_0 = 0
 
     #: NULL-ENCRYPT [:rfc:`2410`]
     NULL_ENCRYPT = 1
@@ -41,16 +41,16 @@ class HIAlgorithm(IntEnum):
     ECDSA_LOW = 9
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'HIAlgorithm':
         """Backport support for original codes."""
         if isinstance(key, int):
             return HIAlgorithm(key)
         if key not in HIAlgorithm._member_map_:  # pylint: disable=no-member
             extend_enum(HIAlgorithm, key, default)
-        return HIAlgorithm[key]
+        return HIAlgorithm[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'HIAlgorithm':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 65535):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
