@@ -11,7 +11,7 @@ class NATTraversal(IntEnum):
     """[NATTraversal] HIP NAT Traversal Modes"""
 
     #: Reserved [:rfc:`5770`]
-    Reserved = 0
+    Reserved_0 = 0
 
     #: UDP-ENCAPSULATION [:rfc:`5770`]
     UDP_ENCAPSULATION = 1
@@ -19,21 +19,24 @@ class NATTraversal(IntEnum):
     #: ICE-STUN-UDP [:rfc:`5770`]
     ICE_STUN_UDP = 2
 
+    #: ICE-HIP-UDP [:rfc:`9028`]
+    ICE_HIP_UDP = 3
+
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'NATTraversal':
         """Backport support for original codes."""
         if isinstance(key, int):
             return NATTraversal(key)
         if key not in NATTraversal._member_map_:  # pylint: disable=no-member
             extend_enum(NATTraversal, key, default)
-        return NATTraversal[key]
+        return NATTraversal[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'NATTraversal':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 65535):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
-        if 3 <= value <= 65535:
+        if 4 <= value <= 65535:
             #: Unassigned
             extend_enum(cls, 'Unassigned_%d' % value, value)
             return cls(value)
