@@ -11,49 +11,49 @@ class Packet(IntEnum):
     """[Packet] HIP Packet Types"""
 
     #: Reserved [:rfc:`7401`]
-    Reserved = 0
+    Reserved_0 = 0
 
-    #: I1 [:rfc:`7401`] the HIP Initiator Packet
+    #: I1 the HIP Initiator Packet [:rfc:`7401`]
     I1 = 1
 
-    #: R1 [:rfc:`7401`] the HIP Responder Packet
+    #: R1 the HIP Responder Packet [:rfc:`7401`]
     R1 = 2
 
-    #: I2 [:rfc:`7401`] the Second HIP Initiator Packet
+    #: I2 the Second HIP Initiator Packet [:rfc:`7401`]
     I2 = 3
 
-    #: R2 [:rfc:`7401`] the Second HIP Responder Packet
+    #: R2 the Second HIP Responder Packet [:rfc:`7401`]
     R2 = 4
 
-    #: UPDATE [:rfc:`7401`] the HIP Update Packet
+    #: UPDATE the HIP Update Packet [:rfc:`7401`]
     UPDATE = 16
 
-    #: NOTIFY [:rfc:`7401`] the HIP Notify Packet
+    #: NOTIFY the HIP Notify Packet [:rfc:`7401`]
     NOTIFY = 17
 
-    #: CLOSE [:rfc:`7401`] the HIP Association Closing Packet
+    #: CLOSE the HIP Association Closing Packet [:rfc:`7401`]
     CLOSE = 18
 
-    #: CLOSE_ACK [:rfc:`7401`] the HIP Closing Acknowledgment Packet
+    #: CLOSE_ACK the HIP Closing Acknowledgment Packet [:rfc:`7401`]
     CLOSE_ACK = 19
 
-    #: HDRR [:rfc:`6537`] HIP Distributed Hash Table Resource Record
+    #: HDRR (HIP Distributed Hash Table Resource Record) [:rfc:`6537`]
     HDRR = 20
 
     #: HIP_DATA [:rfc:`6078`]
     HIP_DATA = 32
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Packet':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Packet(key)
         if key not in Packet._member_map_:  # pylint: disable=no-member
             extend_enum(Packet, key, default)
-        return Packet[key]
+        return Packet[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Packet':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 127):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
