@@ -27,16 +27,16 @@ class ClassificationLevel(IntEnum):
     Reserved_1 = 0b11110001
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'ClassificationLevel':
         """Backport support for original codes."""
         if isinstance(key, int):
             return ClassificationLevel(key)
         if key not in ClassificationLevel._member_map_:  # pylint: disable=no-member
             extend_enum(ClassificationLevel, key, default)
-        return ClassificationLevel[key]
+        return ClassificationLevel[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'ClassificationLevel':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0b00000000 <= value <= 0b11111111):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
