@@ -27,16 +27,16 @@ class ProtectionAuthority(IntEnum):
     Field_Termination_Indicator = 7
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'ProtectionAuthority':
         """Backport support for original codes."""
         if isinstance(key, int):
             return ProtectionAuthority(key)
         if key not in ProtectionAuthority._member_map_:  # pylint: disable=no-member
             extend_enum(ProtectionAuthority, key, default)
-        return ProtectionAuthority[key]
+        return ProtectionAuthority[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'ProtectionAuthority':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 7):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
