@@ -19,16 +19,16 @@ class ToSECN(IntEnum):
     CE = 0b11
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'ToSECN':
         """Backport support for original codes."""
         if isinstance(key, int):
             return ToSECN(key)
         if key not in ToSECN._member_map_:  # pylint: disable=no-member
             extend_enum(ToSECN, key, default)
-        return ToSECN[key]
+        return ToSECN[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'ToSECN':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0b00 <= value <= 0b11):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
