@@ -27,16 +27,16 @@ class ToSPrecedence(IntEnum):
     Routine = 0
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'ToSPrecedence':
         """Backport support for original codes."""
         if isinstance(key, int):
             return ToSPrecedence(key)
         if key not in ToSPrecedence._member_map_:  # pylint: disable=no-member
             extend_enum(ToSPrecedence, key, default)
-        return ToSPrecedence[key]
+        return ToSPrecedence[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'ToSPrecedence':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0b000 <= value <= 0b111):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
