@@ -224,16 +224,16 @@ class RouterAlert(IntEnum):
     Reserved_65535 = 65535
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'RouterAlert':
         """Backport support for original codes."""
         if isinstance(key, int):
             return RouterAlert(key)
         if key not in RouterAlert._member_map_:  # pylint: disable=no-member
             extend_enum(RouterAlert, key, default)
-        return RouterAlert[key]
+        return RouterAlert[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'RouterAlert':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 65535):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
