@@ -23,16 +23,16 @@ class TaggerID(IntEnum):
     IPv6 = 3
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'TaggerID':
         """Backport support for original codes."""
         if isinstance(key, int):
             return TaggerID(key)
         if key not in TaggerID._member_map_:  # pylint: disable=no-member
             extend_enum(TaggerID, key, default)
-        return TaggerID[key]
+        return TaggerID[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'TaggerID':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 7):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
