@@ -40,7 +40,7 @@ class Packet(IntEnum):
     #: Fast Binding Acknowledgment [:rfc:`5568`]
     Fast_Binding_Acknowledgment = 9
 
-    #: Fast Neighbor Advertisement [:rfc:`5568`] (Deprecated)
+    #: Fast Neighbor Advertisement (Deprecated) [:rfc:`5568`]
     Fast_Neighbor_Advertisement = 10
 
     #: Experimental Mobility Header [:rfc:`5096`]
@@ -83,16 +83,16 @@ class Packet(IntEnum):
     Subscription_Response = 23
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Packet':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Packet(key)
         if key not in Packet._member_map_:  # pylint: disable=no-member
             extend_enum(Packet, key, default)
-        return Packet[key]
+        return Packet[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Packet':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 255):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
