@@ -11,7 +11,7 @@ class Packet(IntEnum):
     """[Packet] OSPF Packet Types"""
 
     #: Reserved
-    Reserved = 0
+    Reserved_0 = 0
 
     #: Hello [:rfc:`2328`]
     Hello = 1
@@ -29,16 +29,16 @@ class Packet(IntEnum):
     Link_State_Ack = 5
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Packet':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Packet(key)
         if key not in Packet._member_map_:  # pylint: disable=no-member
             extend_enum(Packet, key, default)
-        return Packet[key]
+        return Packet[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Packet':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 65535):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
