@@ -19,16 +19,16 @@ class Checksum(IntEnum):
     Redundant_Checksum_Avoidance = 3
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Checksum':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Checksum(key)
         if key not in Checksum._member_map_:  # pylint: disable=no-member
             extend_enum(Checksum, key, default)
-        return Checksum[key]
+        return Checksum[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Checksum':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 255):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
