@@ -10,53 +10,53 @@ __all__ = ['Option']
 class Option(IntEnum):
     """[Option] TCP Option Kind Numbers"""
 
-    #: End of Option List [:rfc:`793`]
-    EOOL = 0
+    #: End of Option List [RFC-ietf-tcpm-rfc793bis-28]
+    End_of_Option_List = 0
 
-    #: No-Operation [:rfc:`793`]
-    NOP = 1
+    #: No-Operation [RFC-ietf-tcpm-rfc793bis-28]
+    No_Operation = 1
 
-    #: Maximum Segment Size [:rfc:`793`]
-    MSS = 2
+    #: Maximum Segment Size [RFC-ietf-tcpm-rfc793bis-28]
+    Maximum_Segment_Size = 2
 
     #: Window Scale [:rfc:`7323`]
-    WS = 3
+    Window_Scale = 3
 
     #: SACK Permitted [:rfc:`2018`]
-    SACKPMT = 4
+    SACK_Permitted = 4
 
     #: SACK [:rfc:`2018`]
     SACK = 5
 
     #: Echo (obsoleted by option 8) [:rfc:`1072`][:rfc:`6247`]
-    ECHO = 6
+    Echo = 6
 
     #: Echo Reply (obsoleted by option 8) [:rfc:`1072`][:rfc:`6247`]
-    ECHORE = 7
+    Echo_Reply = 7
 
     #: Timestamps [:rfc:`7323`]
-    TS = 8
+    Timestamps = 8
 
     #: Partial Order Connection Permitted (obsolete) [:rfc:`1693`][:rfc:`6247`]
-    POC = 9
+    Partial_Order_Connection_Permitted = 9
 
     #: Partial Order Service Profile (obsolete) [:rfc:`1693`][:rfc:`6247`]
-    POCSP = 10
+    Partial_Order_Service_Profile = 10
 
     #: CC (obsolete) [:rfc:`1644`][:rfc:`6247`]
     CC = 11
 
     #: CC.NEW (obsolete) [:rfc:`1644`][:rfc:`6247`]
-    CCNEW = 12
+    CC_NEW = 12
 
     #: CC.ECHO (obsolete) [:rfc:`1644`][:rfc:`6247`]
-    CCECHO = 13
+    CC_ECHO = 13
 
     #: TCP Alternate Checksum Request (obsolete) [:rfc:`1146`][:rfc:`6247`]
-    CHKREQ = 14
+    TCP_Alternate_Checksum_Request = 14
 
     #: TCP Alternate Checksum Data (obsolete) [:rfc:`1146`][:rfc:`6247`]
-    CHKSUM = 15
+    TCP_Alternate_Checksum_Data = 15
 
     #: Skeeter [Stev Knowles]
     Skeeter = 16
@@ -68,7 +68,7 @@ class Option(IntEnum):
     Trailer_Checksum_Option = 18
 
     #: MD5 Signature Option (obsoleted by option 29) [:rfc:`2385`]
-    SIG = 19
+    MD5_Signature_Option = 19
 
     #: SCPS Capabilities [Keith Scott]
     SCPS_Capabilities = 20
@@ -86,23 +86,23 @@ class Option(IntEnum):
     SNAP = 24
 
     #: Unassigned (released 2000-12-18)
-    Unassigned = 25
+    Unassigned_25 = 25
 
     #: TCP Compression Filter [Steve Bellovin]
     TCP_Compression_Filter = 26
 
     #: Quick-Start Response [:rfc:`4782`]
-    QS = 27
+    Quick_Start_Response = 27
 
     #: User Timeout Option (also, other known unauthorized use) [***][1]
     #: [:rfc:`5482`]
-    TIMEOUT = 28
+    User_Timeout_Option = 28
 
     #: TCP Authentication Option (TCP-AO) [:rfc:`5925`]
-    AO = 29
+    TCP_Authentication_Option = 29
 
     #: Multipath TCP (MPTCP) [:rfc:`8684`]
-    MP = 30
+    Multipath_TCP = 30
 
     #: Reserved (known unauthorized use without proper IANA assignment) [**]
     Reserved_31 = 31
@@ -114,7 +114,7 @@ class Option(IntEnum):
     Reserved_33 = 33
 
     #: TCP Fast Open Cookie [:rfc:`7413`]
-    FASTOPEN = 34
+    TCP_Fast_Open_Cookie = 34
 
     #: Encryption Negotiation (TCP-ENO) [:rfc:`8547`]
     Encryption_Negotiation = 69
@@ -140,16 +140,16 @@ class Option(IntEnum):
     RFC3692_style_Experiment_2 = 254
 
     @staticmethod
-    def get(key, default=-1):
+    def get(key: 'int | str', default: 'int' = -1) -> 'Option':
         """Backport support for original codes."""
         if isinstance(key, int):
             return Option(key)
         if key not in Option._member_map_:  # pylint: disable=no-member
             extend_enum(Option, key, default)
-        return Option[key]
+        return Option[key]  # type: ignore[misc]
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: 'int') -> 'Option':
         """Lookup function used when value is not found."""
         if not (isinstance(value, int) and 0 <= value <= 255):
             raise ValueError('%r is not a valid %s' % (value, cls.__name__))
