@@ -8,13 +8,13 @@ with detailed implementation and methods.
 """
 # TODO: Implement specified classes for MAC and IP addresses.
 
+from typing import TYPE_CHECKING
+
 # Base Class for Protocols
 from pcapkit.protocols.protocol import Protocol
 
 # Utility Classes for Protocols
-from pcapkit.protocols.raw import *
-from pcapkit.protocols.null import *
-from pcapkit.protocols.pcap import *
+from pcapkit.protocols.misc import *
 
 # Protocols & Macros
 from pcapkit.protocols.link import *
@@ -22,15 +22,10 @@ from pcapkit.protocols.internet import *
 from pcapkit.protocols.transport import *
 from pcapkit.protocols.application import *
 
-# Deprecated / Base Protocols
-from pcapkit.protocols.internet.ip import IP
-from pcapkit.protocols.internet.ipsec import IPsec
-from pcapkit.protocols.application.http import HTTP
+if TYPE_CHECKING:
+    from typing import Type
 
 __all__ = [
-    # Protocol Numbers
-    'LINKTYPE', 'ETHERTYPE', 'TP_PROTO',
-
     # PCAP Headers
     'Header', 'Frame',
 
@@ -55,5 +50,15 @@ __all__ = [
     'TCP', 'UDP',
 
     # Application Layer
-    'FTP', 'HTTP',
+    'FTP', 'HTTP', 'HTTPv1', 'HTTPv2',
 ]
+
+# protocol registry
+__proto__ = {}  # type: dict[str, Type[Protocol]]
+for name in __all__:
+    __proto__[name.upper()] = globals()[name]
+
+__all__.extend((
+    # Protocol Numbers
+    'LINKTYPE', 'ETHERTYPE', 'TRANSTYPE',
+))
