@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# pylint: disable=unused-import,fixme
 """application layer protocols
 
 `pcapkit.protocols.application` is collection of all
@@ -6,8 +7,9 @@ protocols in application layer, with detailed
 implementation and methods.
 
 """
-# TODO: Implements BGP, DHCP, DNS, IMAP, IDAP, MQTT, NNTP, NTP,
-#       ONC:RPC, POP, RIP, RTP, SIP, SMTP, SNMP, SSH, SSL, TELNET, TLS, XMPP.
+# TODO: Implements BGP, DHCP, DHCPv6, DNS, IMAP, LDAP, MQTT,
+#       NNTP, NTP, ONC:RPC, POP, RIP, RTP, SIP, SMTP, SNMP,
+#       SSH, TELNET, TLS/SSL, XMPP.
 
 # Base Class for Internet Layer
 from pcapkit.protocols.application.application import Application
@@ -20,4 +22,4 @@ from pcapkit.protocols.application.httpv2 import HTTPv2
 # Deprecated / Base Classes
 from pcapkit.protocols.application.http import HTTP
 
-__all__ = ['FTP', 'HTTPv1', 'HTTPv2']
+__all__ = ['FTP', 'HTTP', 'HTTPv1', 'HTTPv2']
