@@ -12,53 +12,35 @@ Security (IPsec) protocol family [*]_, eg.
 .. [*] https://en.wikipedia.org/wiki/IPsec
 
 """
-from pcapkit.protocols.internet.ip import IP
-from pcapkit.utilities.exceptions import UnsupportedCall
+from typing import TYPE_CHECKING, Generic
 
-__all__ = 'IPsec'
+from pcapkit.protocols.internet.internet import Internet
+from pcapkit.protocols.protocol import PT
+
+if TYPE_CHECKING:
+    from typing_extensions import Literal
+
+__all__ = ['IPsec']
 
 
-class IPsec(IP):  # pylint: disable=abstract-method
+class IPsec(Internet[PT], Generic[PT]):  # pylint: disable=abstract-method
     """Abstract base class for IPsec protocol family.
 
     - Authentication Header (:class:`~pcapkit.protocols.internet.ah.AH`) [:rfc:`4302`]
     - Encapsulating Security Payload (:class:`~pcapkit.protocols.internet.esp.ESP`) [:rfc:`4303`]
 
     """
-    ##########################################################################
-    # Properties.
-    ##########################################################################
-
-    @property
-    def src(self):
-        """Source IP address.
-
-        Raises:
-            UnsupportedCall: This protocol doesn't support :attr:`src`.
-
-        """
-        raise UnsupportedCall(f"'{self.__class__.__name__}' object has no attribute 'src'")
-
-    @property
-    def dst(self):
-        """Destination IP address.
-
-        Raises:
-            UnsupportedCall: This protocol doesn't support :attr:`dst`.
-
-        """
-        raise UnsupportedCall(f"'{self.__class__.__name__}' object has no attribute 'dst'")
 
     ##########################################################################
     # Data models.
     ##########################################################################
 
     @classmethod
-    def id(cls):
+    def id(cls) -> 'tuple[Literal["AH"], Literal["ESP"]]':
         """Index ID of the protocol.
 
         Returns:
-            Tuple[Literal['AH'], Literal['ESP']]: Index ID of the protocol.
+            Index ID of the protocol.
 
         """
         return ('AH', 'ESP')
