@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# pylint: disable=unused-import,unused-wildcard-import,fixme
 """transport layer protocols
 
 `pcapkit.protocols.transport` is collection of all protocols
@@ -6,7 +7,7 @@ in transport layer, with detailed implementation and
 methods.
 
 """
-# TODO: Implements DCCP, RSVP, STCP.
+# TODO: Implements DCCP, RSVP, SCTP.
 
 # Base Class for Transport Layer
 from pcapkit.protocols.transport.transport import Transport
@@ -16,10 +17,9 @@ from pcapkit.protocols.transport.tcp import TCP
 from pcapkit.protocols.transport.udp import UDP
 
 # Transport Layer Protocol Numbers
-from pcapkit.protocols.transport.transport import TP_PROTO
-
+from pcapkit.const.reg.transtype import TransType as TRANSTYPE
 
 __all__ = [
-    'TP_PROTO',     # Protocol Numbers
-    'TCP', 'UDP',   # Transport Layer Protocols
+    'TRANSTYPE',   # Protocol Numbers
+    'TCP', 'UDP',  # Transport Layer Protocols
 ]
