@@ -14,8 +14,13 @@ import os
 import struct
 import sys
 import traceback
+from typing import TYPE_CHECKING
 
 from pcapkit.utilities.compat import ModuleNotFoundError  # pylint: disable=redefined-builtin
+from pcapkit.utilities.logging import DEVMODE, logger
+
+if TYPE_CHECKING:
+    from typing import Any
 
 __all__ = [
     'stacklevel',
@@ -26,30 +31,22 @@ __all__ = [
     'DictError', 'ListError', 'TupleError', 'IterableError',        # TypeError
     'IOObjError', 'ProtocolUnbound', 'CallableError',               # TypeError
     'InfoError', 'IPError', 'EnumError', 'ComparisonError',         # TypeError
+    'RegistryError',                                                # TypeError
     'FormatError', 'UnsupportedCall',                               # AttributeError
     'FileError',                                                    # IOError
     'FileExists',                                                   # FileExistsError
     'FileNotFound',                                                 # FileNotFoundError
     'ProtocolNotFound',                                             # IndexError
     'VersionError', 'IndexNotFound', 'ProtocolError',               # ValueError
-    'EndianError',                                                  # ValueError
+    'EndianError', 'KeyExists',                                     # ValueError
     'ProtocolNotImplemented', 'VendorNotImplemented',               # NotImplementedError
     'StructError',                                                  # struct.error
-    'FragmentError', 'PacketError',                                 # KeyError
+    'MissingKeyError', 'FragmentError', 'PacketError',              # KeyError
     'ModuleNotFound',                                               # ModuleNotFoundError
 ]
 
-# boolean mappings
-BOOLEAN_STATES = {'1': True, '0': False,
-                  'yes': True, 'no': False,
-                  'true': True, 'false': False,
-                  'on': True, 'off': False}
 
-#: Development mode (``DEVMODE``) flag.
-DEVMODE = BOOLEAN_STATES.get(os.environ.get('PCAPKIT_DEVMODE', 'false').casefold(), False)
-
-
-def stacklevel():
+def stacklevel() -> 'int':
     """Fetch current stack level.
 
     The function will walk through the straceback stack (:func:`traceback.extract_stack`),
@@ -57,7 +54,7 @@ def stacklevel():
     display any disturbing internal traceback information when raising errors.
 
     Returns:
-        int: Stack level until internal stacks, i.e. contains ``/pcapkit/``.
+        Stack level until internal stacks, i.e. contains ``/pcapkit/``.
 
     """
     pcapkit = f'{os.path.sep}pcapkit{os.path.sep}'
@@ -85,7 +82,7 @@ class BaseError(Exception):
 
           .. note::
 
-            This note is deprecated since Python fixed the problem above.
+             This note is deprecated since Python fixed the problem above.
 
         * In Python 2.7, :func:`trace.print_stack(limit)` dose not support negative limit.
 
@@ -93,21 +90,21 @@ class BaseError(Exception):
         :func:`pcapkit.utilities.exceptions.stacklevel`
 
     """
-    def __init__(self, *args, quiet=False, **kwargs):
-        if DEVMODE:
-            index = stacklevel()
-            if not quiet and index:
-                fmt_exc = traceback.format_exc(limit=-index)
-                if len(fmt_exc.splitlines(True)) > 1:
-                    print(fmt_exc, file=sys.stderr)
-        else:
+
+    def __init__(self, *args: 'Any', quiet: 'bool' = False, **kwargs: 'Any') -> 'None':
+        # log error
+        if not quiet:
+            if DEVMODE:
+                logger.error('%s: %s', type(self).__name__, str(self), exc_info=self,
+                             stack_info=True, stacklevel=-stacklevel())
+                # logger.error('%s: %s', type(self).__name__, str(self))
+            else:
+                logger.error('%s: %s', type(self).__name__, str(self))
+
+        if not DEVMODE:
             sys.tracebacklimit = 0
         super().__init__(*args, **kwargs)
 
-        # log error
-        from pcapkit.utilities.logging import logger  # pylint: disable=import-outside-toplevel
-        logger.error(str(self), exc_info=self)
-
 
 ##############################################################################
 # TypeError session.
@@ -190,6 +187,10 @@ class ComparisonError(BaseError, TypeError):
     """Rich comparison not supported between instances."""
 
 
+class RegistryError(BaseError, TypeError):
+    """The argument(s) must be *registry* type."""
+
+
 ##############################################################################
 # AttributeError session.
 ##############################################################################
@@ -263,6 +264,10 @@ class EndianError(BaseError, ValueError):
     """Invalid endian (byte order)."""
 
 
+class KeyExists(BaseError, ValueError):
+    """Key already exists."""
+
+
 ##############################################################################
 # NotImplementedError session.
 ##############################################################################
@@ -284,12 +289,20 @@ class VendorNotImplemented(BaseError, NotImplementedError):
 class StructError(BaseError, struct.error):
     """Unpack failed."""
 
+    def __init__(self, *args: 'Any', eof: 'bool' = False, **kwargs: 'Any') -> 'None':
+        self.eof = eof
+        super().__init__(*args, **kwargs)
+
 
 ##############################################################################
 # KeyError session.
 ##############################################################################
 
 
+class MissingKeyError(BaseError, KeyError):
+    """Key not found."""
+
+
 class FragmentError(BaseError, KeyError):
     """Invalid fragment dict."""
 
