@@ -5,6 +5,13 @@
 
 """
 import warnings
+from typing import TYPE_CHECKING
+
+from pcapkit.utilities.exceptions import stacklevel as stacklevel_calculator
+from pcapkit.utilities.logging import DEVMODE, logger
+
+if TYPE_CHECKING:
+    from typing import Any, Optional, Type, Union
 
 __all__ = [
     'warn',
@@ -17,20 +24,21 @@ __all__ = [
     'FileWarning', 'LayerWarning', 'ProtocolWarning', 'AttributeWarning',
     'DevModeWarning', 'VendorRequestWarning', 'VendorRuntimeWarning',
     # ResourceWarning
-    'DPKTWarning', 'ScapyWarning', 'PySharkWarning'
+    'DPKTWarning', 'ScapyWarning', 'PySharkWarning', 'EmojiWarning',
+    'VendorWarning',
 ]
 
 
-def warn(message, category, stacklevel=None):
+def warn(message: 'Union[str, Warning]', category: 'Type[Warning]',
+         stacklevel: 'Optional[int]' = None) -> 'None':
     """Wrapper function of :func:`warnings.warn`.
 
     Args:
-        message (Union[str, Warning]): Warning message.
-        category (Type[Warning]): Warning category.
-        stacklevel (Optional[int]): Warning stack level.
+        message: Warning message.
+        category: Warning category.
+        stacklevel: Warning stack level.
 
     """
-    from pcapkit.utilities.exceptions import stacklevel as stacklevel_calculator  # pylint: disable=import-outside-toplevel
     if stacklevel is None:
         stacklevel = stacklevel_calculator()
     warnings.warn(message, category, stacklevel)
@@ -44,14 +52,16 @@ def warn(message, category, stacklevel=None):
 class BaseWarning(UserWarning):
     """Base warning class of all kinds."""
 
-    def __init__(self, *args, **kwargs):  # pylint: disable=useless-super-delegation
+    def __init__(self, *args: 'Any', **kwargs: 'Any') -> 'None':  # pylint: disable=useless-super-delegation
+        # log warning
+        if DEVMODE:
+            logger.warning(str(self), exc_info=self)
+        else:
+            logger.warning(str(self))
+
         # warnings.simplefilter('default')
         super().__init__(*args, **kwargs)
 
-        # log warning
-        from pcapkit.utilities.logging import logger  # pylint: disable=import-outside-toplevel
-        logger.warning(str(self), exc_info=self)
-
 
 ##############################################################################
 # ImportWarning session.
@@ -118,3 +128,11 @@ class ScapyWarning(BaseWarning, ResourceWarning):
 
 class PySharkWarning(BaseWarning, ResourceWarning):
     """Warnings on PyShark usage."""
+
+
+class EmojiWarning(BaseWarning, ResourceWarning):
+    """Warnings on Emoji usage."""
+
+
+class VendorWarning(BaseWarning, ResourceWarning):
+    """Warnings on vendor usage."""
